@@ -53,9 +53,7 @@ class PKCachedSession(CachedSession):
 userDataDirComponents = Archiver.get_user_data_dir().split(os.sep)
 session = PKCachedSession(
     cache_name=f"{os.sep.join(userDataDirComponents[-2:])}{os.sep}PKDevTools_cache",
-    db_path=os.path.join(
-    Archiver.get_user_data_dir(),
-     "PKDevTools_cache.sqlite"),
+    db_path=os.path.join(Archiver.get_user_data_dir(),"PKDevTools_cache.sqlite"),
     expire_after=timedelta(hours=6),
     stale_if_error=True,
 )
