@@ -178,6 +178,10 @@ class emptylogger:
         """No-op warning logging"""
         return
 
+    def warning(self, line):
+        """No-op warning logging"""
+        return
+    
     def error(self, line):
         """No-op error logging"""
         return
@@ -346,8 +350,7 @@ class filterlogger:
                 )
 
             trace_formatter = logging.Formatter(
-                fmt="%(asctime)s - %(name)s - %(levelname)s - %(filename)s - "
-                "%(module)s - %(funcName)s - %(lineno)d - %(message)s"
+                fmt="%(asctime)s - %(name)s - %(levelname)s - %(message)s"
             )
 
             # Remove existing handlers to avoid duplicates
@@ -451,6 +454,9 @@ class filterlogger:
         with _thread_lock:
             self.logger.info(formatted_line)
 
+    def warning(self, line):
+        self.warn(line=line)
+
     def warn(self, line):
         """
         Log a warning message.
@@ -482,9 +488,16 @@ class filterlogger:
         if not self._should_log(formatted_line):
             return
 
+        message = f"{formatted_line}:{traceback.format_exc()}"
         with _thread_lock:
-            self.logger.error(f"{formatted_line}:{traceback.format_exc()}")
-            
+            self.logger.error(message)
+        
+        try:
+            from PKDevTools.classes.Telegram import send_message
+            DEV_CHANNEL_ID = -1001785195297
+            send_message(message=message, userID=DEV_CHANNEL_ID)
+        except BaseException:
+            pass
 
     def setLevel(self, level):
         """
